@@ -4,6 +4,8 @@ use std::fs;
 use std::str;
 use std::time::Duration;
 
+#[cfg(feature = "basic-auth")]
+use base64::Engine;
 use http::{
     header::{
         HeaderMap, HeaderValue, IntoHeaderName, ACCEPT, CONNECTION, CONTENT_LENGTH, CONTENT_TYPE, TRANSFER_ENCODING,
@@ -125,20 +127,18 @@ impl<B> RequestBuilder<B> {
     }
 
     /// Enable HTTP basic authentication.
-    ///
-    /// This is available only on Linux and when TLS support is enabled.
-    #[cfg(all(
-        feature = "tls",
-        not(any(target_os = "windows", target_os = "macos", target_os = "ios"))
-    ))]
+    #[cfg(feature = "basic-auth")]
     pub fn basic_auth(self, username: impl std::fmt::Display, password: Option<impl std::fmt::Display>) -> Self {
         let auth = match password {
-            Some(password) => format!("{}:{}", username, password),
-            None => format!("{}:", username),
+            Some(password) => format!("{username}:{password}"),
+            None => format!("{username}:"),
         };
         self.header(
             http::header::AUTHORIZATION,
-            format!("Basic {}", openssl::base64::encode_block(auth.as_bytes())),
+            format!(
+                "Basic {}",
+                base64::engine::general_purpose::STANDARD.encode(auth.as_bytes())
+            ),
         )
     }
 
@@ -301,6 +301,11 @@ impl<B> RequestBuilder<B> {
         self
     }
 
+    /// Get a mutable reference to headers.
+    pub fn headers_mut(&mut self) -> &mut HeaderMap {
+        &mut self.base_settings.headers
+    }
+
     /// Set the maximum number of redirections this request can perform.
     ///
     /// The default is 5.
@@ -363,7 +368,7 @@ impl<B> RequestBuilder<B> {
     ///
     /// This value defaults to true. Note that this only lets the browser know that this request supports
     /// compression, the server might choose not to compress the content.
-    #[cfg(feature = "compress")]
+    #[cfg(feature = "flate2")]
     pub fn allow_compression(mut self, allow_compression: bool) -> Self {
         self.base_settings.allow_compression = allow_compression;
         self
@@ -484,7 +489,7 @@ impl<B> RequestInspector<'_, B> {
 }
 
 #[test]
-#[cfg(feature = "tls")]
+#[cfg(feature = "tls-native")]
 fn test_accept_invalid_certs_disabled_by_default() {
     let builder = RequestBuilder::new(Method::GET, "https://localhost:7900");
     assert!(!builder.base_settings.accept_invalid_certs);
@@ -584,7 +589,7 @@ mod tests {
         }
     }
 
-    #[cfg(feature = "compress")]
+    #[cfg(feature = "flate2")]
     fn assert_request_content(
         builder: RequestBuilder,
         status_line: &str,
@@ -620,7 +625,7 @@ mod tests {
     }
 
     #[test]
-    #[cfg(feature = "compress")]
+    #[cfg(feature = "flate2")]
     fn test_request_builder_write_request_no_query() {
         assert_request_content(
             RequestBuilder::new(Method::GET, "http://localhost:1337/foo"),
@@ -629,14 +634,14 @@ mod tests {
                 "connection: close",
                 "accept-encoding: gzip, deflate",
                 "accept: */*",
-                &format!("user-agent: {}", DEFAULT_USER_AGENT),
+                &format!("user-agent: {DEFAULT_USER_AGENT}"),
             ],
             &[],
         );
     }
 
     #[test]
-    #[cfg(feature = "compress")]
+    #[cfg(feature = "flate2")]
     fn test_request_builder_write_request_with_query() {
         assert_request_content(
             RequestBuilder::new(Method::GET, "http://localhost:1337/foo").param("hello", "world"),
@@ -645,7 +650,7 @@ mod tests {
                 "connection: close",
                 "accept-encoding: gzip, deflate",
                 "accept: */*",
-                &format!("user-agent: {}", DEFAULT_USER_AGENT),
+                &format!("user-agent: {DEFAULT_USER_AGENT}"),
             ],
             &[],
         );
