@@ -18,9 +18,7 @@ impl TlsHandshaker {
 
     pub fn danger_accept_invalid_hostnames(&mut self, _accept_invalid_hostnames: bool) {}
 
-    pub fn add_root_certificate(&mut self, _cert: Certificate) -> Result<()> {
-        Ok(())
-    }
+    pub fn add_root_certificate(&mut self, _cert: Certificate) {}
 
     pub fn handshake<S>(&self, _domain: &str, _stream: S) -> Result<TlsStream<S>>
     where
